@@ -10,20 +10,20 @@
  * Find more information about this on the LICENSE file.
  */
 
-define(['../module'], function(directives) {
+define(['../module'], function (directives) {
   'use strict'
-  directives.directive('wzKbnSwitch', function(BASE_URL) {
+  directives.directive('wzKbnSwitch', function (BASE_URL) {
     return {
       restrict: 'E',
       scope: {
         switchModel: '=switchModel',
         switchChange: '&',
-        switchText: '@switchText'
+        switchText: '@switchText',
       },
       controller() {},
       templateUrl:
         BASE_URL +
-        '/static/app/SplunkAppForWazuh/js/directives/wz-kbn-switch/wz-kbn-switch.html'
+        '/static/app/SplunkAppForWazuh/js/directives/wz-kbn-switch/wz-kbn-switch.html',
     }
   })
 })
