@@ -6,7 +6,6 @@ define([
   './apiIndexStorageService/apiIndexStorageService',
   './api-manager/apiMgrService',
   './dataService/dataService',
-  './rules/rulesDescription',
   './tableFilterService/tableFilterService',
   './key-equivalence/keyEquivalenceService',
   './currentDataService/currentDataService',
@@ -16,7 +15,6 @@ define([
   './notificationService/notificationService',
   './csv-request/csvRequestService',
   './xml-beautifier/xml-beautifier',
-  './get-ids/getIdService',
   './token-model/urlTokenModelService',
   './group-handler/group-handler',
   './date-diff/dateDiffService',
@@ -29,8 +27,7 @@ define([
   './splunk-services/splunk-users',
   './validationService/validationService',
   './requirementService/requirementService',
-  './security_services/actions_enum',
-  './security_services/security_service',
+  './security/securityService',
   './security/rule/ruleService',
   './security/role/roleService',
   './security/policy/policyService',
